@@ -11,11 +11,11 @@ def setup_cmdline_args_for_docly_gen(parser: ArgumentParser):
     parser.add_argument("--no_print_report", action="store_false",
                         help="Do not prompt to show the report once the diff is generated")
     parser.add_argument("--run_on_notebooks", action="store_true",
-                        help="!!EXPERIMENTAL!! If you want docly to run on notebook (.ipynb) files (Requires jupytext and defaults false)")
+                        help="If you want docly to run on notebook (.ipynb) files (Requires jupytext and defaults false)")
     #####################
     # Unused at the moment.
     parser.add_argument("--docstring_style", type=str, default="google", 
-                        help="What style of docstring you want. Defaults to Google style")
+                        help="What style of docstring you want [google, numpy, sphinx]. Defaults to `google` style.")
     #####################
     parser.add_argument("--config_file", type=str, default="docly-config.ini",
                         help="Configuration file for docly")
